;+
; NAME: 
;       INPAINT_KEPLER
;
; PURPOSE: 
;       gaps filled with inpainting
;
; CALLING:
;       inpaint_kepler,in,out,out_ng=out_ng,max_sz_gap=max_sz_gap,dt=dt
;
; INPUTS: 
;       data --- irregularly sampled time series
;	
; OUTPUT: 
;       inp_reg --- inpainted regular sampled data
;
; KEYWORD:
;       dt --- regular timing
;       out_irreg --- contains the original data with its original timing
;                  + gap filled with regular timing => *** Introduce WINDOW EFFECTS ****
;       max_sz_gap --- maximal size of gaps to be filled in inp_irreg
;       wdw_inp --- window with the interpolated points (1-original ; 2-interpolated ; 0 - unchanged)
;
; HISTORY:
;	Written: Rafael A. Garcia Aug. 2013
;       Modified by Sandrine Pires Oct. 2013
;-
;---------------------------------------------------------
PRO inpaint_kepler, data, inp_reg, out_reg_gap=out_reg_gap, out_irreg=out_irreg, max_sz_gap=max_sz_gap,dt=dt,verbose=verbose,sigmabounded=sigmabounded,wdw_inp=wdw_inp
IF not Keyword_set(sigmabounded) then sigmabounded=0
IF not Keyword_set(verbose) then verbose=0

  regular_grid,data,data_reg,dt=dt,out_irreg=out_irreg
  t = REFORM(data_reg(0,*))
  flux = REFORM(data_reg(1,*))  
  bad = where(flux eq 0.0)
  run_mca1d, flux,iflux,verbose=verbose,sigmabounded=sigmabounded
  np = n_elements(iflux)
  inp_reg = dblarr(2,np)
  inp_reg(0,*) = t
  inp_reg(1,*) = flux
  inp_reg(1,bad) = iflux(bad)
  wdw_inp = replicate(1,n_elements(flux))
  wdw_inp(bad) = 2
  IF not keyword_set(max_sz_gap) THEN BEGIN
      out_irreg(1,bad) = iflux(bad)
  ENDIF ELSE BEGIN
     new_window,data,inp_reg,max_sz_gap,wdw_inp=wdw_inp ;out_irreg  ; Don't use in KEPLER data
  ENDELSE
END
