;+
; NAME: 
;       NEW_WINDOW
;
; PURPOSE: 
;       Inpaint only the gaps with a length smaller than max_sz_gap
;
; CALLING:
;       new_window,data,out,out_ng,max_sz_gap
;
; INPUTS: 
;       data --- irregularly sampled time series
;	
; OUTPUT: 
;       inp_reg --- inpainted regular sampled data
;
; KEYWORD:
;       inp_irreg --- contains the original data with its original timing
;                  + gap filled with regular timing
;       max_sz_gap --- maximal size of gaps to be filled in out_ng
;
; HISTORY:
;	Written: R. Garcia 2013
;-
;---------------------------------------------------------
PRO new_window,data,inp_reg,max_sz_gap,inp_irreg=inp_irreg,wdw_inp=wdw_inp
  time_org = reform(data(0,*))
  dif = time_org(1:*)-time_org(0:*)
  indx = WHERE(dif gt max_sz_gap,nn)       ; Indexes of the initial times of the big gaps
  IF indx(0) gt -1 THEN BEGIN
       IF KEYWORD_SET(inp_irreg) THEN BEGIN
            For i=0,nn-1 DO BEGIN
              a = WHERE(inp_irreg(0,*) gt time_org(indx(i)) and inp_irreg(0,*) lt time_org(indx(i)+1)) ; We select the big gaps
              IF a(0) gt -1 THEN inp_irreg(1,a) = !values.f_nan     ; We put NaNs in the big gaps
            ENDFOR
            a = WHERE(FINITE(inp_irreg(1,*)) eq 1)
            inp_irreg = inp_irreg(*,a)  ; We remove the NaNs
       ENDIF
       FOR i=0,nn-1 DO BEGIN
           a = WHERE(inp_reg(0,*) gt time_org(indx(i)) and inp_reg(0,*) lt time_org(indx(i)+1)) ; We select the big gaps
           IF a(0) gt -1 THEN  BEGIN
               inp_reg(1,a) = 0.0     ; We put the big gaps to zero
               wdw_inp(a) = 0
          ENDIF     
      ENDFOR  
 ENDIF
 
END
