;+
; NAME: 
;       PSD
;
; PURPOSE: 
;       Estimate the power spectrum using the generalized Lomb-Scargle Perodogram
;
; CALLING:
;
; INPUTS: 
;       kraw --- incomplete 1d raw signal
;	
; OUTPUT: 
;       freq --- frequency in Hz
;       pot --- power spectrum in ppm^2/Hz
; KEYWORD:
;	    
;
; HISTORY:
;	Written: S. Pires Nov. 2012
;-
;---------------------------------------------------------
PRO psd,data,freq, pot,ofac=ofac,plot=plot
        ; Data(0,*) in days
        If not keyword_set(ofac) THEN ofac=1
        np=n_elements(data(0,*))
        t=reform(data(0,*)-data(0,0))*86400.   ; time in seconds with t0=0
        res=reform(data(1,*))   ;
        gd=where(Finite(res) eq 1)
        ;IF keyword_set(plot) THEN plot,t,res,/yn
        dtav=Double(mean(data(0,gd(1:*))-data(0,gd(0:*)))*86400.d0)    ; Dc correction, average dt
        dtmed=Double(median(data(0,1:*)-data(0,0:*))*86400.d0)  ; Dc Correction, median dt
                if dtmed eq 0 then dtmed=dtav
        a=lnp_test(t(gd),res(gd),/double,wk1=freq,wk2=pow, ofac=ofac,hifac=dtav/dtmed)
        ; Correction by Parceval
    	length=max(t)/86400.
    	res_var=moment(res(gd), /double)
    	var=res_var(1)
    	pot=pow*var/total(pow, /double)/((freq(1)-freq(0))*1e6)
    	IF keyword_set(plot) THEN PLOT_oo,freq*1e6,pot,background=255,col=0,charsize=2,xst=1,xtit='Frequency (!7l!6Hz)',ytit='PSD (ppm!u2!n/Hz)'
END
