;+
; NAME: 
;       REGULAR_GRID
;
; PURPOSE: 
;       Puts the points of data into a regular grid with
;       dt=median(real dt)
;       Points where there are no points are set to zero
;
; CALLING:
;       regular_grid,data,out,dt=dt,out_ng=out_ng
;
; INPUTS: 
;       data --- irregularly sampled 1d signal
;	
; OUTPUT: 
;       out_reg ---  regularly sampled signal with gaps
;
; KEYWORD:
;       dt --- regular timing value
;       maxi --- to just process the beginning of the time series
;       aver --- resize with larger bien
;       out_irreg --- out no gap: existing points are in the original
;                  timing, gaps are filled with regular grid
;                       IT DOES NOT WORK WHEN AVERAGING!!
;
; HISTORY:
;	Written: R. Garcia 2013
;-
;---------------------------------------------------------
PRO regular_grid,data,out_reg,dt=dt,maxi=maxi,aver=aver,out_irreg=out_irreg
 
  t=(data(0,*)-data(0,0))
  gd=where(finite(data(1,*)) eq 1)
  IF not keyword_set(dt) THEN  dt=double(median(t(1:*)-t(0:*)))
  if not keyword_set(maxi) then begin 
    fin = max(t)
  ENDIF ELSE BEGIN
    fin = maxi
  ENDELSE
  np_int = round((fin+dt)/dt)
  out_reg = dblarr(2,np_int)

  out_reg(0,*) = lindgen(np_int)*dt   
  IF not keyword_Set(aver) THEN BEGIN
    ndx = round(t(gd)/dt)
    out_reg(1,ndx) = data(1,gd)
    out_irreg = out_reg
    out_irreg(0,*) = out_irreg(0,*)+data(0,0)
    out_irreg(0,ndx) = data(0,gd)
  ENDIF ELSE BEGIN
    gd = WHERE(finite(data(1,*)) eq 1 and data(1,*) ne 0.0)
    ndx=round(t(gd)/dt)
    FOR i=0, np_int -1 DO BEGIN
      a=where(i eq ndx,na)
      IF a(0) gt -1 THEN out_reg(1,i)=total(data(1,gd(a)))/double(na)
    ENDFOR
  ENDELSE
  out_reg(0,*)=out_reg(0,*)+data(0,0)

END
