;+
; NAME: 
;       RUN_MCA1D
;
; PURPOSE: 
;       process the inpainting of an incomplete 1d signal 
;       using Multiscale Discrete Cosine Transform
;
; CALLING:
;       run_mca1d, in_data, out_data, /expo
;
; INPUTS: 
;       in_data --- incomplete 1d signal
;	
; OUTPUT: 
;       out_data --- inpainted data	
;
; KEYWORD:
;      iter --- number of iterations
;      plot --- plot the result of inpainting
;      verbose --- verbose mode
;      write --- write the original and inpainted signal
;      sigmabounded --- sigma bounded per scale
;      nscale --- To fix the number of scales in the MDCT
;      dct --- if the gaps are in the same dynamic use the DCT 
;
; HISTORY:
;	Written: S. Pires Nov. 2012
;-
;---------------------------------------------------------
pro run_mca1d, in_data, out_data, iter=iter, plot= plot, verbose = verbose, write=write, sigmabounded=sigmabounded, nscale=nscale, dct=dct
;, noise=noise

;Signal should be around zero to make inapinting work
ind = where(in_data ne 0)
nind = where(in_data eq 0)
m = mean(in_data(ind)) 
print, 'mean = ', m 
print, 'noise = ', sigma(re(fft(in_data(ind))))
in_data2 = in_data-mean(in_data(ind))  
in_data2(nind) = 0

mgap = size_gap(in_data2)

if not keyword_set(nscale) then nscale = fix(alog(mgap)/alog(2))+1.
y = fix(alog(mgap*8.)/alog(2))+1.
DCTBlockSize = long(2.^y)

name1 = ''
if keyword_set(sigmabounded) then name1 = ' -d'
name2 = ''


;sig = get_noise(Imag)
;if keyword_set(noise) then sig = sigma(re(fft(in_data2)))
;name2 = ' -s0 -g'+string(sig) +' '


if not keyword_set(iter) then iter =100


if keyword_set(dct) then begin
  y = fix(alog(n_elements(in_data))/alog(2))
  DCTBlockSize = long(2.^y)
  if keyword_set(verbose) then begin
    print, '**** DCTBlockSize = ', DCTBlockSize
    print, '**** ITER = ', iter
    cb_mca1d, in_data2, out_data2, opt='-H -s0 -t3 -O -B'+string(DCTBlockSize)+' -L -v -i'+string(iter)+' -D2 '+name1+name2
  endif else begin
    cb_mca1d, in_data2, out_data2, opt='-H -s0 -t3 -O -B'+string(DCTBlockSize)+' -L -i'+string(iter)+' -D2 '+name1+name2
  endelse
endif else begin
  if keyword_set(verbose) then begin
    print, '**** NSCALE = ', nscale
    print, '**** DCTBlockSize = ', DCTBlockSize
    print, '**** ITER = ', iter
    com = '-H -s0 -n'+string(nscale)+' -t4 -O -B'+string(DCTBlockSize)+' -L -v -i'+string(iter)+' -D2'+name1+name2
    print, com
    cb_mca1d, in_data2, out_data2, opt='-H -s0 -n'+string(nscale)+' -t4 -O -B'+string(DCTBlockSize)+' -L -v -i'+string(iter)+' -D2'+name1+name2  
  endif else begin
    com = '-H -s0 -n'+string(nscale)+' -t4 -O -B'+string(DCTBlockSize)+' -L -i'+string(iter)+' -D2 '+name1+name2
    print, com
    cb_mca1d, in_data2, out_data2, opt='-H -s0 -n'+string(nscale)+' -t4 -O -B'+string(DCTBlockSize)+' -L -i'+string(iter)+' -D2 '+name1+name2
  endelse
endelse

out_data = out_data2 + m

if keyword_set(plot) then begin
  tek_color
  window, 0, xsize=1000, ysize=350
  plot, in_data  
  oplot, out_data, color=2
endif

if keyword_set(writefits) then begin
  writefits, 'Signal.fits', in_data
  writefits, 'Signal_inp.fits', out_data
endif


end
